about summary refs log tree commit diff stats
path: root/.emacs.d/lisp
diff options
context:
space:
mode:
Diffstat (limited to '.emacs.d/lisp')
-rw-r--r--.emacs.d/lisp/init-lsp.el5
1 files changed, 3 insertions, 2 deletions
diff --git a/.emacs.d/lisp/init-lsp.el b/.emacs.d/lisp/init-lsp.el
index a66cf28..18856c4 100644
--- a/.emacs.d/lisp/init-lsp.el
+++ b/.emacs.d/lisp/init-lsp.el
@@ -40,9 +40,10 @@
         lsp-modeline-code-actions-enable nil
         lsp-modeline-diagnostics-enable nil
         lsp-treemacs-theme "Iconless"
         ;; user cider for indendation and completion instead
         lsp-enable-indentation nil
-        lsp-completion-enable nil))
+        lsp-completion-enable nil
+        lsp-eldoc-enable-hover nil))
 
 (provide 'init-lsp)
 ;;; init-lsp.el ends here
@@ -40,9 +40,10 @@
         lsp-modeline-diagnostics-enable nil
         lsp-treemacs-theme "Iconless"
-        ;; user cider for indendation and completion instead
+        ;; user cider for indendation, completion and eldoc instead
         lsp-enable-indentation nil